@@ -19,6 +19,7 @@
 
 #include <KItinerary/CountryDb>
 
+#include <knowledgedb/alphaid.h>
 #include <knowledgedb/trainstationdb.h>
 
 #include <QDebug>
@@ -60,6 +61,31 @@ private Q_SLOTS:
         QVERIFY(uic[0] != uic[1]);
     }
 
+   void testAlphaId()
+   {
+       using ID3 = AlphaId<uint16_t, 3>;
+       constexpr ID3 id1{"ABC"};
+       const ID3 id2(QStringLiteral("CBA"));
+       static_assert(sizeof(id1) == 2, "");
+       QVERIFY(id1.isValid());
+       QVERIFY(id2.isValid());
+       QVERIFY(id1 < id2);
+       QVERIFY(!(id2 < id1));
+       QVERIFY(id1 == id1);
+       QVERIFY(id1 != id2);
+       QVERIFY(!(id1 == id2));
+       QVERIFY(!(id1 != id1));
+
+       QCOMPARE(id1.toString(), QLatin1String("ABC"));
+       QCOMPARE(id2.toString(), QLatin1String("CBA"));
+
+       constexpr ID3 id3;
+       QVERIFY(!id3.isValid());
+       QVERIFY(id3.toString().isEmpty());
+
+       qDebug() << id1;
+    }
+
     void testIBNRLookup()
     {
         auto station = KnowledgeDb::stationForIbnr(IBNR{1234567});
@@ -145,7 +171,7 @@ private Q_SLOTS:
         QCOMPARE(country.drivingSide, KnowledgeDb::DrivingSide::Left);
         QCOMPARE(country.powerPlugTypes, {TypeG});
         country = KnowledgeDb::countryForId(CountryId{"GL"});
-        QCOMPARE(country.drivingSide, KnowledgeDb::DrivingSide::Unknown);
+        QCOMPARE(country.drivingSide, KnowledgeDb::DrivingSide::Right);
     }
 
     void testPowerPlugCompat_data()
@@ -197,6 +223,38 @@ private Q_SLOTS:
         QCOMPARE(KnowledgeDb::timezoneForCountry(CountryId{"FR"}).toQTimeZone(), QTimeZone("Europe/Paris"));
         QCOMPARE(KnowledgeDb::timezoneForCountry(CountryId{"BR"}).toQTimeZone(), QTimeZone());
     }
+
+    void testUICCountryCodeLookup()
+    {
+        using namespace KnowledgeDb;
+
+        QCOMPARE(KnowledgeDb::countryIdForUicCode(80), CountryId{"DE"});
+        QCOMPARE(KnowledgeDb::countryIdForUicCode(0), CountryId{});
+    }
+
+    void testIso3Lookup()
+    {
+        using namespace KnowledgeDb;
+
+        QCOMPARE(KnowledgeDb::countryIdFromIso3166_1alpha3(CountryId3{"ITA"}), CountryId{"IT"});
+        QCOMPARE(KnowledgeDb::countryIdFromIso3166_1alpha3(CountryId3{"FOO"}), CountryId{});
+    }
+
+    void testIndianRailwaysStationCodeLookup()
+    {
+        auto station = KnowledgeDb::stationForIndianRailwaysStationCode(QString());
+        QVERIFY(!station.coordinate.isValid());
+        QCOMPARE(station.timezone.toQTimeZone(), QTimeZone());
+
+        station = KnowledgeDb::stationForIndianRailwaysStationCode(QStringLiteral("NDLS"));
+        QVERIFY(station.coordinate.isValid());
+        QCOMPARE(station.timezone.toQTimeZone(), QTimeZone("Asia/Kolkata"));
+        QCOMPARE(station.country, CountryId{"IN"});
+
+        station = KnowledgeDb::stationForIndianRailwaysStationCode(QStringLiteral("ndls"));
+        QVERIFY(!station.coordinate.isValid());
+        QCOMPARE(station.timezone.toQTimeZone(), QTimeZone());
+    }
 };
 
 QTEST_APPLESS_MAIN(KnowledgeDbTest)
