@@ -93,6 +93,40 @@ private Q_SLOTS:
         QVERIFY(!LocationUtil::isSameLocation(txl, {}, LocationUtil::CityLevel));
         QVERIFY(!LocationUtil::isSameLocation({}, sxf, LocationUtil::Exact));
     }
+
+    void testLocationNameCompare_data()
+    {
+        QTest::addColumn<QString>("lhsName");
+        QTest::addColumn<QString>("rhsName");
+        QTest::addColumn<bool>("cityEqual");
+        QTest::addColumn<bool>("exactEqual");
+
+        QTest::newRow("empty") << QString() << QString() << false << false;
+        QTest::newRow("equal") << QStringLiteral("Berlin") << QStringLiteral("Berlin") << true << true;
+        QTest::newRow("not equal") << QStringLiteral("Nürnberg") << QStringLiteral("Valencia") << false << false;
+        QTest::newRow("case-insenstive") << QStringLiteral("Berlin") << QStringLiteral("BERLiN") << true << true;
+        QTest::newRow("diacritic") << QStringLiteral("Düsseldorf") << QStringLiteral("Dusseldorf") << true << true;
+        QTest::newRow("diacritic 2") << QStringLiteral("Rīga") << QStringLiteral("Riga") << true << true;
+        QTest::newRow("diacritic case-insensitive") << QStringLiteral("København H") << QStringLiteral("KOEBENHAVN H") << true << true;
+        QTest::newRow("diacritic transliteration") << QStringLiteral("Zürich") << QStringLiteral("ZUERICH") << true << true;
+    }
+
+    void testLocationNameCompare()
+    {
+        QFETCH(QString, lhsName);
+        QFETCH(QString, rhsName);
+        QFETCH(bool, cityEqual);
+        QFETCH(bool, exactEqual);
+
+        Place lhs;
+        lhs.setName(lhsName);
+        Place rhs;
+        rhs.setName(rhsName);
+        QCOMPARE(LocationUtil::isSameLocation(lhs, rhs, LocationUtil::CityLevel), cityEqual);
+        QCOMPARE(LocationUtil::isSameLocation(rhs, lhs, LocationUtil::CityLevel), cityEqual);
+        QCOMPARE(LocationUtil::isSameLocation(lhs, rhs, LocationUtil::Exact), exactEqual);
+        QCOMPARE(LocationUtil::isSameLocation(rhs, lhs, LocationUtil::Exact), exactEqual);
+    }
 };
 
 QTEST_APPLESS_MAIN(LocationUtilTest)
