@@ -29,6 +29,8 @@ class EventPrivate: public QSharedData {
 
 public:
     QString name;
+    QString description;
+    QUrl image;
     QUrl url;
     QDateTime startDate;
     QDateTime endDate;
@@ -38,6 +40,8 @@ public:
 
 KITINERARY_MAKE_SIMPLE_CLASS(Event)
 KITINERARY_MAKE_PROPERTY(Event, QString, name, setName)
+KITINERARY_MAKE_PROPERTY(Event, QString, description, setDescription)
+KITINERARY_MAKE_PROPERTY(Event, QUrl, image, setImage)
 KITINERARY_MAKE_PROPERTY(Event, QUrl, url, setUrl)
 KITINERARY_MAKE_PROPERTY(Event, QDateTime, startDate, setStartDate)
 KITINERARY_MAKE_PROPERTY(Event, QDateTime, endDate, setEndDate)
