@@ -29,20 +29,26 @@ class OrganizationPrivate: public QSharedData
     KITINERARY_PRIVATE_BASE_GADGET(Organization)
 public:
     QString name;
+    QString description;
+    QUrl image;
     QString email;
     QString telephone;
     QUrl url;
     PostalAddress address;
     GeoCoordinates geo;
+    QVariantList potentialAction;
 };
 
 KITINERARY_MAKE_BASE_CLASS(Organization)
 KITINERARY_MAKE_PROPERTY(Organization, QString, name, setName)
+KITINERARY_MAKE_PROPERTY(Organization, QString, description, setDescription)
+KITINERARY_MAKE_PROPERTY(Organization, QUrl, image, setImage)
 KITINERARY_MAKE_PROPERTY(Organization, QString, email, setEmail)
 KITINERARY_MAKE_PROPERTY(Organization, QString, telephone, setTelephone)
 KITINERARY_MAKE_PROPERTY(Organization, QUrl, url, setUrl)
 KITINERARY_MAKE_PROPERTY(Organization, PostalAddress, address, setAddress)
 KITINERARY_MAKE_PROPERTY(Organization, KItinerary::GeoCoordinates, geo, setGeo)
+KITINERARY_MAKE_PROPERTY(Organization, QVariantList, potentialAction, setPotentialAction)
 KITINERARY_MAKE_OPERATOR(Organization)
 
 class AirlinePrivate : public OrganizationPrivate
