@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "place.h"
@@ -68,7 +68,7 @@ public:
 };
 
 KITINERARY_MAKE_SIMPLE_CLASS(PostalAddress)
-KITINERARY_MAKE_PROPERTY(PostalAddress, QString, streetAddress, setStreeAddress)
+KITINERARY_MAKE_PROPERTY(PostalAddress, QString, streetAddress, setStreetAddress)
 KITINERARY_MAKE_PROPERTY(PostalAddress, QString, addressLocality, setAddressLocality)
 KITINERARY_MAKE_PROPERTY(PostalAddress, QString, postalCode, setPostalCode)
 KITINERARY_MAKE_PROPERTY(PostalAddress, QString, addressRegion, setAddressRegion)
