@@ -43,11 +43,13 @@ KITINERARY_MAKE_OPERATOR(Seat)
 class TicketPrivate : public QSharedData
 {
 public:
+    QString name;
     Seat ticketedSeat;
     QString ticketToken;
 };
 
 KITINERARY_MAKE_SIMPLE_CLASS(Ticket)
+KITINERARY_MAKE_PROPERTY(Ticket, QString, name, setName)
 KITINERARY_MAKE_PROPERTY(Ticket, Seat, ticketedSeat, setTicketedSeat)
 KITINERARY_MAKE_PROPERTY(Ticket, QString, ticketToken, setTicketToken)
 KITINERARY_MAKE_OPERATOR(Ticket)
@@ -60,6 +62,8 @@ Ticket::TicketTokenType Ticket::ticketTokenType() const
         return AztecCode;
     } else if (d->ticketToken.startsWith(QLatin1String("barcode128:"), Qt::CaseInsensitive)) {
         return Code128;
+    } else if (d->ticketToken.startsWith(QLatin1String("datamatrix:"), Qt::CaseInsensitive)) {
+        return DataMatrix;
     } else if (d->ticketToken.startsWith(QLatin1String("http"), Qt::CaseInsensitive)) {
         return Url;
     }
@@ -77,6 +81,8 @@ QString Ticket::ticketTokenData() const
         return QString::fromLatin1(b.constData(), b.size());
     } else if (d->ticketToken.startsWith(QLatin1String("barcode128:"), Qt::CaseInsensitive)) {
         return ticketToken().mid(11);
+    } else if (d->ticketToken.startsWith(QLatin1String("datamatrix:"), Qt::CaseInsensitive)) {
+        return ticketToken().mid(11);
     }
     return ticketToken();
 }
