@@ -51,7 +51,7 @@ class ExtractorRepositoryPrivate;
  *
  *  See KItinerary::Extractor on where this loads its content from.
  */
-class ExtractorRepository
+class KITINERARY_EXPORT ExtractorRepository
 {
 public:
     ExtractorRepository();
@@ -59,16 +59,33 @@ public:
     ExtractorRepository(ExtractorRepository &&) noexcept;
     ExtractorRepository(const ExtractorRepository &) = delete;
 
+    /** Reload the extractor repository.
+     *  Not needed during normal operations, this is mainly for tooling.
+     */
+    void reload();
+
+    /** All known extractors. */
+    const std::vector<Extractor>& allExtractors() const;
+
     /** Finds matching extractors for the given message part. */
-    std::vector<const Extractor *> extractorsForMessage(KMime::Content *part) const;
+    void extractorsForMessage(KMime::Content *part, std::vector<Extractor> &extractors) const;
     /** Finds matching extractors for the given pkpass boarding pass. */
-    std::vector<const Extractor *> extractorsForPass(KPkPass::Pass *pass) const;
+    void extractorsForPass(KPkPass::Pass *pass, std::vector<Extractor> &extractors) const;
     /** Finds matching extractors for the given JSON-LD data provided by generic extractors. */
-    std::vector<const Extractor *> extractorsForJsonLd(const QJsonArray &data) const;
+    void extractorsForJsonLd(const QJsonArray &data, std::vector<Extractor> &extractors) const;
     /** Finds matching extractors for the given barcode string. */
-    std::vector<const Extractor *> extractorsForBarcode(const QString &code) const;
+    void extractorsForBarcode(const QString &code, std::vector<Extractor> &extractors) const;
     /** Find matching extractors for the given iCal calendar. */
-    std::vector<const Extractor *> extractorsForCalendar(const QSharedPointer<KCalendarCore::Calendar> &cal) const;
+    void extractorsForCalendar(const QSharedPointer<KCalendarCore::Calendar> &cal, std::vector<Extractor> &extractors) const;
+    /** Find matching extractors for the given content. */
+    void extractorsForContent(const QString &content, std::vector<Extractor> &extractors) const;
+    /** Returns the extractor with the given identifier. */
+    Extractor extractor(const QString &name) const;
+
+    /** Returns the list of additional search paths for extractor scripts. */
+    QStringList additionalSearchPaths() const;
+    /** Sets additional search paths to look for extractors. */
+    void setAdditionalSearchPaths(const QStringList &searchPaths);
 
 private:
     ExtractorRepositoryPrivate* d;
