@@ -22,10 +22,7 @@ function extractColumn(page, offset) {
     if (!text.match(/FLIGHT \d+/))
         return null;
 
-    var res = JsonLd.newObject("FlightReservation");
-    res.reservationFor = JsonLd.newObject("Flight");
-    res.reservedTicket = JsonLd.newObject("Ticket");
-
+    var res = JsonLd.newFlightReservation();
     var images = page.imagesInRect(offset, 0, offset + 0.5, 1);
     for (var i = 0; i < images.length; ++i) {
         if (images[i].width < 300 && images[i].height < images[i].width) {
