@@ -16,3 +16,17 @@
 */
 
 #include "context.h"
+
+using namespace KItinerary;
+
+QJSValue JsApi::Context::data() const
+{
+    return m_data;
+}
+
+void JsApi::Context::reset()
+{
+    m_barcode = {};
+    m_pdfPageNum = -1;
+    m_data = {};
+}
