@@ -44,11 +44,23 @@ public:
      *  This can be used by extractor scripts to fill in the extracted information.
      */
     Q_INVOKABLE QJSValue newFlightReservation() const;
+    /** Convenience method that generates a full TrainReservation JS object.
+     *  This can be used by extractor scripts to fill in the extracted information.
+     */
+    Q_INVOKABLE QJSValue newTrainReservation() const;
+    /** Convenience method that generates a full BusReservation JS object.
+     *  This can be used by extractor scripts to fill in the extracted information.
+     */
+    Q_INVOKABLE QJSValue newBusReservation() const;
     /** Convenience method that generates a full LodgingReservation JS object.
      *  This can be used by extractor scripts to fill in the extracted information.
      */
     Q_INVOKABLE QJSValue newLodgingReservation() const;
-    // TODO add the same for other reservation types
+    /** Convenience method that generates a full EventReservation JS object.
+     *  This can be used by extractor scripts to fill in the extracted information.
+     */
+    Q_INVOKABLE QJSValue newEventReservation() const;
+    // TODO add the same for restaurant and car rental reservation types
 
     /** Convert a date/time string to a date/time value.
      *  @param dtStr The input string containing a date/time value.
@@ -81,6 +93,7 @@ public:
     void setContextDate(const QDateTime &dt);
     ///@endcond
 private:
+    QJSValue newPlace(const QString &type) const;
     QJSEngine *m_engine;
     QDateTime m_contextDate;
 };
