@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KITINERARY_GENERATOR_CODEGEN_H
@@ -33,7 +33,7 @@ class Timezones;
 namespace CodeGen
 {
     void writeLicenseHeader(QIODevice *out);
-    void writeCoordinate(QIODevice *out, const KnowledgeDb::Coordinate &coord);
+    void writeCoordinate(QIODevice *out, KnowledgeDb::Coordinate coord);
     void writeCountryIsoCode(QIODevice *out, const QString &isoCode);
     void writeTimezone(QIODevice *out, const QByteArray &tzName);
     void writeTimezoneEnum(QIODevice *out, const QByteArray &tzName);
