@@ -53,6 +53,7 @@ private:
     bool fetchIBNR();
     bool fetchUIC();
     bool fetchGaresConnexions();
+    bool fetchIndianRailwaysStationCode();
     bool fetchCountryInformation();
     QUrl insertOrMerge(const QJsonObject &obj, bool mergeOnly = false);
     void processStations();
@@ -60,12 +61,14 @@ private:
     void writeIBNRMap(QIODevice *out);
     void writeUICMap(QIODevice *out);
     void writeGareConnexionMap(QIODevice *out);
+    void writeIndianRailwaysMap(QIODevice *out);
     void printSummary();
 
     std::vector<Station> m_stations;
     std::map<uint32_t, QUrl> m_ibnrMap;
     std::map<uint32_t, QUrl> m_uicMap;
     std::map<QString, QUrl> m_garesConnexionsIdMap;
+    std::map<QString, QUrl> m_indianRailwaysMap;
     Timezones m_tzDb;
 
     int m_idConflicts = 0;
