@@ -28,21 +28,6 @@ using namespace KItinerary::KnowledgeDb;
 
 static_assert(sizeof(CountryId) <= 2, "CountryId too large");
 
-CountryId::CountryId(const QString& id)
-{
-    m_id1 = m_id2 = 0;
-    m_unused = 0;
-
-    if (id.size() != 2) {
-        return;
-    }
-    if (!id.at(0).isUpper() || !id.at(1).isUpper()) {
-        return;
-    }
-    m_id1 = id.at(0).toLatin1() - '@';
-    m_id2 = id.at(1).toLatin1() - '@';
-}
-
 Country KnowledgeDb::countryForId(CountryId id)
 {
     const auto it = std::lower_bound(std::begin(country_table), std::end(country_table), id, [](const Country &lhs, CountryId rhs) {
@@ -64,15 +49,6 @@ const Country* KnowledgeDb::countriesEnd()
     return std::end(country_table);
 }
 
-QString KnowledgeDb::CountryId::toString() const
-{
-    QString s;
-    s.resize(2);
-    s[0] = QLatin1Char('@' + m_id1);
-    s[1] = QLatin1Char('@' + m_id2);
-    return s;
-}
-
 struct PowerPlugCompatMap {
     PowerPlugType plug;
     PowerPlugTypes sockets;
@@ -83,7 +59,7 @@ static const PowerPlugCompatMap power_plug_compat_map[] = {
     { TypeB, TypeB },
     { TypeC, TypeC | TypeE | TypeF | TypeH | TypeJ | TypeK | TypeL | TypeN },
     { TypeD, TypeD },
-    { TypeE, TypeE | TypeF | TypeK }, // TypeE <-> TypeF not strictly correct, but in practise almost always compatible
+    { TypeE, TypeE | TypeF | TypeK }, // TypeE <-> TypeF not strictly correct, but in practice almost always compatible
     { TypeF, TypeE | TypeF | TypeK },
     { TypeG, TypeG },
     { TypeH, TypeH },
@@ -123,4 +99,28 @@ PowerPlugTypes KnowledgeDb::incompatiblePowerSockets(PowerPlugTypes plugs, Power
     return failSockets & ~plugs;
 }
 
+KnowledgeDb::CountryId KnowledgeDb::countryIdFromIso3166_1alpha3(CountryId3 iso3Code)
+{
+    const auto it = std::lower_bound(std::begin(iso_country_code_table), std::end(iso_country_code_table), iso3Code, [](const auto &lhs, CountryId3 rhs) {
+        return lhs.iso3Code < rhs;
+    });
+    if (it == std::end(iso_country_code_table) || (*it).iso3Code != iso3Code) {
+        return {};
+    }
+
+    return (*it).iso2Code;
+}
+
+KnowledgeDb::CountryId KnowledgeDb::countryIdForUicCode(uint16_t uicCountryCode)
+{
+    const auto it = std::lower_bound(std::begin(uic_country_code_table), std::end(uic_country_code_table), uicCountryCode, [](const auto &lhs, uint16_t rhs) {
+        return lhs.uicCode < rhs;
+    });
+    if (it == std::end(uic_country_code_table) || (*it).uicCode != uicCountryCode) {
+        return {};
+    }
+
+    return (*it).isoCode;
+}
+
 #include "moc_countrydb.cpp"
