@@ -19,12 +19,12 @@
 #define KITINERARY_POPPLERTYPES_P_H
 
 #include <config-kitinerary.h>
+#include <qglobal.h>
 
-#ifdef HAVE_POPPLER_0_82
+#if KPOPPLER_VERSION >= QT_VERSION_CHECK(0, 82, 0)
 using PopplerMaskColors = const int;
 #else
 using PopplerMaskColors = int;
 #endif
 
 #endif // KITINERARY_POPPLERTYPES_P_H
-
