@@ -25,6 +25,7 @@
 #include <KItinerary/Place>
 #include <KItinerary/RentalCar>
 #include <KItinerary/Reservation>
+#include <KItinerary/Ticket>
 #include <KItinerary/TrainTrip>
 #include <KItinerary/Visit>
 
@@ -33,10 +34,38 @@
 
 using namespace KItinerary;
 
-QDateTime SortUtil::startDateTime(const QVariant &res)
+QDateTime SortUtil::startDateTime(const QVariant &elem)
 {
-    if (JsonLd::isA<FlightReservation>(res)) {
-        const auto flight = res.value<FlightReservation>().reservationFor().value<Flight>();
+    // reservation types
+    if (JsonLd::isA<FoodEstablishmentReservation>(elem)) {
+        return elem.value<FoodEstablishmentReservation>().startTime();
+    }
+    if (JsonLd::isA<LodgingReservation>(elem)) {
+        const auto hotel = elem.value<LodgingReservation>();
+        // hotel checkin/checkout is always considered the first/last thing of the day
+        auto dt = QDateTime(hotel.checkinTime().date(), QTime(23, 59, 59));
+        if (hotel.checkinTime().timeSpec() == Qt::TimeZone) {
+            dt.setTimeZone(hotel.checkinTime().timeZone());
+        }
+        return dt;
+    }
+    if (JsonLd::isA<RentalCarReservation>(elem)) {
+        return elem.value<RentalCarReservation>().pickupTime();
+    }
+    if (JsonLd::isA<TaxiReservation>(elem)) {
+        return elem.value<TaxiReservation>().pickupTime();
+    }
+    if (JsonLd::canConvert<Reservation>(elem)) {
+        const auto res = JsonLd::convert<Reservation>(elem).reservationFor();
+        return startDateTime(res);
+    }
+    if (JsonLd::isA<TouristAttractionVisit>(elem)) {
+        return elem.value<TouristAttractionVisit>().arrivalTime();
+    }
+
+    // "reservationFor" types
+    if (JsonLd::isA<Flight>(elem)) {
+        const auto flight = elem.value<Flight>();
         if (flight.departureTime().isValid()) {
             return flight.departureTime();
         }
@@ -45,76 +74,38 @@ QDateTime SortUtil::startDateTime(const QVariant &res)
         }
         return QDateTime(flight.departureDay(), QTime(23, 59, 59));
     }
-    if (JsonLd::isA<TrainReservation>(res)) {
-        const auto trip = res.value<TrainReservation>().reservationFor().value<TrainTrip>();
+    if (JsonLd::isA<TrainTrip>(elem)) {
+        const auto trip = elem.value<TrainTrip>();
         if (trip.departureTime().isValid()) {
             return trip.departureTime();
         }
         return QDateTime(trip.departureDay(), QTime(23, 59, 59));
     }
-    if (JsonLd::isA<BusReservation>(res)) {
-        return res.value<BusReservation>().reservationFor().value<BusTrip>().departureTime();
+    if (JsonLd::isA<BusTrip>(elem)) {
+        return elem.value<BusTrip>().departureTime();
     }
-    if (JsonLd::isA<FoodEstablishmentReservation>(res)) {
-        return res.value<FoodEstablishmentReservation>().startTime();
-    }
-    if (JsonLd::isA<RentalCarReservation>(res)) {
-        return res.value<RentalCarReservation>().pickupTime();
-    }
-    if (JsonLd::isA<LodgingReservation>(res)) {
-        const auto hotel = res.value<LodgingReservation>();
-        // hotel checkin/checkout is always considered the first/last thing of the day
-        auto dt = QDateTime(hotel.checkinTime().date(), QTime(23, 59, 59));
-        if (hotel.checkinTime().timeSpec() == Qt::TimeZone) {
-            dt.setTimeZone(hotel.checkinTime().timeZone());
-        }
-        return dt;
-    }
-    if (JsonLd::isA<TouristAttractionVisit>(res)) {
-        return res.value<TouristAttractionVisit>().arrivalTime();
-    }
-    if (JsonLd::isA<EventReservation>(res)) {
-        return res.value<EventReservation>().reservationFor().value<Event>().startDate();
-    }
-    if (JsonLd::isA<TaxiReservation>(res)) {
-        return res.value<TaxiReservation>().pickupTime();
+    if (JsonLd::isA<Event>(elem)) {
+        return elem.value<Event>().startDate();
     }
 
     return {};
 }
 
-QDateTime SortUtil::endDateTime(const QVariant &res)
+QDateTime SortUtil::endDateTime(const QVariant &elem)
 {
-    if (JsonLd::isA<FlightReservation>(res)) {
-        const auto flight = res.value<FlightReservation>().reservationFor().value<Flight>();
-        if (flight.arrivalTime().isValid()) {
-            return flight.arrivalTime();
-        }
-        return QDateTime(flight.departureDay(), QTime(23, 59, 59));
-    }
-    if (JsonLd::isA<TrainReservation>(res)) {
-        const auto trip = res.value<TrainReservation>().reservationFor().value<TrainTrip>();
-        if (trip.arrivalTime().isValid()) {
-            return trip.arrivalTime();
-        }
-        return QDateTime(trip.departureDay(), QTime(23, 59, 59));
-    }
-    if (JsonLd::isA<BusReservation>(res)) {
-        return res.value<BusReservation>().reservationFor().value<BusTrip>().arrivalTime();
-    }
-    if (JsonLd::isA<FoodEstablishmentReservation>(res)) {
-        auto endTime = res.value<FoodEstablishmentReservation>().endTime();
+    // reservation types
+    if (JsonLd::isA<FoodEstablishmentReservation>(elem)) {
+        auto endTime = elem.value<FoodEstablishmentReservation>().endTime();
         if (!endTime.isValid()) {
-            endTime = QDateTime(res.value<FoodEstablishmentReservation>().startTime().date(), QTime(23, 59, 59));
+            endTime = QDateTime(elem.value<FoodEstablishmentReservation>().startTime().date(), QTime(23, 59, 59));
         }
         return endTime;
     }
-    if (JsonLd::isA<RentalCarReservation>(res)) {
-        return res.value<RentalCarReservation>().dropoffTime();
+    if (JsonLd::isA<RentalCarReservation>(elem)) {
+        return elem.value<RentalCarReservation>().dropoffTime();
     }
-
-    if (JsonLd::isA<LodgingReservation>(res)) {
-        const auto hotel = res.value<LodgingReservation>();
+    if (JsonLd::isA<LodgingReservation>(elem)) {
+        const auto hotel = elem.value<LodgingReservation>();
         // hotel checkin/checkout is always considered the first/last thing of the day
         auto dt = QDateTime(hotel.checkoutTime().date(), QTime(0, 0, 0));
         if (hotel.checkoutTime().timeSpec() == Qt::TimeZone) {
@@ -122,11 +113,34 @@ QDateTime SortUtil::endDateTime(const QVariant &res)
         }
         return dt;
     }
-    if (JsonLd::isA<TouristAttractionVisit>(res)) {
-        return res.value<TouristAttractionVisit>().departureTime();
+    if (JsonLd::canConvert<Reservation>(elem)) {
+        const auto res = JsonLd::convert<Reservation>(elem).reservationFor();
+        return endDateTime(res);
     }
-    if (JsonLd::isA<EventReservation>(res)) {
-        return res.value<EventReservation>().reservationFor().value<Event>().endDate();
+    if (JsonLd::isA<TouristAttractionVisit>(elem)) {
+        return elem.value<TouristAttractionVisit>().departureTime();
+    }
+
+    // "reservationFor" types
+    if (JsonLd::isA<Event>(elem)) {
+        return elem.value<Event>().endDate();
+    }
+    if (JsonLd::isA<Flight>(elem)) {
+        const auto flight = elem.value<Flight>();
+        if (flight.arrivalTime().isValid()) {
+            return flight.arrivalTime();
+        }
+        return QDateTime(flight.departureDay(), QTime(23, 59, 59));
+    }
+    if (JsonLd::isA<TrainTrip>(elem)) {
+        const auto trip = elem.value<TrainTrip>();
+        if (trip.arrivalTime().isValid()) {
+            return trip.arrivalTime();
+        }
+        return QDateTime(trip.departureDay(), QTime(23, 59, 59));
+    }
+    if (JsonLd::isA<BusTrip>(elem)) {
+        return elem.value<BusTrip>().arrivalTime();
     }
 
     return {};
@@ -141,6 +155,13 @@ bool SortUtil::isBefore(const QVariant &lhs, const QVariant &rhs)
         if (!lhsRes.underName().isNull() && !rhsRes.underName().isNull() && MergeUtil::isSame(lhsRes.reservationFor(), rhsRes.reservationFor())) {
             const auto lhsUN = lhsRes.underName().value<Person>();
             const auto rhsUN = rhsRes.underName().value<Person>();
+
+            // for multi-ticket reservations for the same person, sort by ticket name
+            if (lhsUN.name() == rhsUN.name()) {
+                const auto lhsTicket = lhsRes.reservedTicket().value<Ticket>();
+                const auto rhsTicket = rhsRes.reservedTicket().value<Ticket>();
+                return lhsTicket.name() < rhsTicket.name();
+            }
             return lhsUN.name() < rhsUN.name();
         }
     }
